@@ -22,30 +22,29 @@ try:
 except ImportError:  # pragma: NO COVER
     import mock
 
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-from proto.marshal.rules import wrappers
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.debugger_v2.services.debugger2 import Debugger2AsyncClient
-from google.cloud.debugger_v2.services.debugger2 import Debugger2Client
-from google.cloud.debugger_v2.services.debugger2 import transports
-from google.cloud.debugger_v2.types import data
-from google.cloud.debugger_v2.types import debugger
 from google.oauth2 import service_account
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules import wrappers
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.debugger_v2.services.debugger2 import (
+    Debugger2AsyncClient,
+    Debugger2Client,
+    transports,
+)
+from google.cloud.debugger_v2.types import data, debugger
 
 
 def client_cert_source_callback():
